#
# spec file for package djv
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.links2linux.org/
#

%define soname  0
Name:           djv
Version:        1.0.5.20150809.a7104da
Release:        pm152.4.1
Summary:        DJV Imaging
License: GPL-2.0
Group:          Productivity/Graphics/Viewers
Url:            http://djv.sourceforge.net/
Source0:        http://git.code.sf.net/p/djv/git#/%{name}-%{version}.tar.xz
# PATCH-FIX-OPENSUSE include.patch avvissu@yandex.ru -- Don't include depending when packaging
Patch1:         djv-1.0.5_include.patch
# PATCH-FIX-OPENSUSE path.patch avvissu@yandex.ru -- Change the default installation path
Patch2:         djv-1.0.5_path.patch
# PATCH-FIX-UPSTREAM link_library.patch avvissu@yandex.ru -- Build with --no-undefined
Patch4:         djv-1.0.5_link_library.patch
# PATCH-FIX-UPSTREAM qt5-5.5.patch avvissu@yandex.ru -- Fix build with Qt5 >= 5.5
Patch5:         djv-1.0.5_qt5-5.5.patch
Patch6:         djv-ffmpeg.patch
Patch7:         djv-runtime_paths.patch
BuildRequires:  cmake >= 3.0
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  shared-mime-info
BuildRequires:  hicolor-icon-theme
# Recommended jpegsrc.v9 instead of libjpeg-turbo
BuildRequires:  libjpeg-devel
BuildRequires:  pkg-config
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(IlmBase) >= 2.2.0
BuildRequires:  pkgconfig(OpenEXR) >= 2.2.0
BuildRequires:  cmake(Qt5Concurrent)
BuildRequires:  cmake(Qt5Core) >= 5.3.0
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  cmake(Qt5OpenGL)
BuildRequires:  cmake(Qt5Svg)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  pkgconfig(glew) >= 1.10.0
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libpng) >= 1.6.8
BuildRequires:  pkgconfig(libswscale)
BuildRequires:  pkgconfig(libtiff-4) >= 4.0.3
BuildRequires:  pkgconfig(zlib) >= 1.2.8
Recommends:     %{name}-doc
Requires:       lib%{name}Core%{soname} = %{version}-%{release}
ExclusiveArch:  x86_64

%description
Professional movie playback software for film production, VFX, and 
computer animation. Key features include:
 * real-time playback of image sequences and movies
 * support for industry standard file formats including Cineon, DPX,
   OpenEXR, and QuickTime
 * command line utilities for batch processing
 
%package -n     lib%{name}Core%{soname}
Summary:        C++ library for realtime MIDI input/ouput
Group:          System/Libraries
Provides:       lib%{name}%{soname} = %{version}-%{release}
Provides:       lib%{name}Gui%{soname} = %{version}-%{release}
Provides:       lib%{name}ViewLib%{soname} = %{version}-%{release}

%description -n lib%{name}Core%{soname}
Professional movie playback software for film production, VFX, and 
computer animation.

This package provides the shared libraries. 
 
%package        plugins
Summary:        DJV plugins
Group:          Productivity/Graphics/Viewers
Requires:       %{name} = %{version}-%{release}

%description    plugins
Professional movie playback software for film production, VFX, and 
computer animation.

This package contains plugins for %{name} apps:
 * Cineon, DPX, IFF, IFL, JPEG, LUT, OpenEXR, PIC, PNG, PPM, RLA, SGI, 
   TIFF, Targa

%package        devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       lib%{name}%{soname} = %{version}-%{release}
Provides:       %{name}Core = %{version}-%{release}
Provides:       %{name}Gui = %{version}-%{release}
Provides:       %{name}ViewLib = %{version}-%{release}

%description    devel
Professional movie playback software for film production, VFX, and 
computer animation.

This package contains header files and libraries needed to develop
application that use %{name}.

%package        doc
Summary:        Documentation for %{name}
Group:          Documentation/HTML
BuildArch:      noarch

%description    doc
Professional movie playback software for film production, VFX, and 
computer animation.

Help documentation for %{name}.

%prep
%setup -q -n %{name}-%{version}

%patch1 -p1
%patch2 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1

# Change exec-path
sed -i '/Exec/s|[/].*|%{name}_view|' $(grep -rl 'djv_view.sh')
sed -i~ /tests/d CMakeLists.txt

%build
%cmake \
      -DCMAKE_SKIP_RPATH=OFF

make %{?_smp_mflags}

%install
%cmake_install
find %{buildroot} -ls

mv -v %{buildroot}%{_prefix}/translations %{buildroot}%{_libdir}/%{name}

# Search and load all plugins
d="%{buildroot}"
for f in `ls $d%{_bindir}/%{name}*`; do
b=$(basename $f)
mv $f $d%{_libdir}/%{name}/
ln -s %{_libdir}/%{name}/$b $d%{_bindir}/$b; done

%suse_update_desktop_file -r %{name}_view Qt Graphics Viewer

%fdupes -s %{buildroot}/%{_datadir}

%check
# Only local test
#sed -i '/ctest/s|\(bin/ctest\)|\1 -V|' build/Makefile
#make test -C build

%post -n lib%{name}Core%{soname} -p /sbin/ldconfig

%postun -n lib%{name}Core%{soname} -p /sbin/ldconfig

%post
%mime_database_post
%desktop_database_post
%icon_theme_cache_post

%postun
%mime_database_postun
%desktop_database_postun
%icon_theme_cache_postun

%files
%defattr(-,root,root)
%doc LICENSE README
%{_bindir}/%{name}_convert
%{_bindir}/%{name}_info
%{_bindir}/%{name}_ls
%{_bindir}/%{name}_view
%{_libdir}/%{name}
%{_datadir}/applications/%{name}_view.desktop
%{_datadir}/mime/packages/%{name}_view*.xml
%{_datadir}/icons/hicolor/*/apps/%{name}_view.png
%exclude %{_libdir}/%{name}/lib%{name}*Plugin.so

%files -n lib%{name}Core%{soname}
%defattr(-,root,root)
%{_libdir}/lib%{name}*.so.*

%files plugins
%defattr(-,root,root)
%{_libdir}/%{name}/lib%{name}*Plugin.so

%files devel
%defattr(-,root,root)
%{_includedir}/%{name}*.h
%{_libdir}/lib%{name}*.so

%files doc
%defattr(-,root,root)
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/doc
%{_datadir}/%{name}/doc

%changelog
* Tue Feb 28 2017 olaf@aepfle.de
- Update to 1.0.5.20150809.a7104da
* Sat Oct 24 2015 avvissu@yandex.ru
- Change group for plugins
* Mon Oct  5 2015 avvissu@yandex.ru
- Fix build on openSUSE > 13.2: djv-1.0.5_qt5-5.5.patch
* Mon Sep 14 2015 avvissu@yandex.ru
- Initial release
